"""
Australian tax report
Inputs: 
- income accounts (i.e. for dividends)
- tax accounts (i.e. for withholding tax)
- the official exchange rates
- base currency

Outputs:
- all taxable income, in base currency (AUD)
- all external income, converted into the base currency
"""

# Read the configuration from the config.py file?